/*
 * LogChannel.java
 *
 * Created on 17 May 2009
 *
 * Version 1.1
 *
 * Copyright (c) Kieran Greer
 *
 */

package org.jlog2.channel;


/**
 * This abstract class provides descriptions of the methods that need to be
 * implemented by a channel that can be used by a logger to log messages.
 * @author Kieran Greer
 */
public abstract class LogChannel
{
    /**
     * Create the log channel.
     * @throws java.lang.Exception any error.
     */
    protected abstract void createLogChannel() throws Exception;

    /**
     * Write the message to the log channel.
     * @param message the message to write.
     * @throws java.lang.Exception any error.
     */
    public abstract void writeMessage(String message) throws Exception;

    /**
     * Write an exception to the log channel.
     * @param message the message to write.
     * @throws java.lang.Exception any error.
     */
    public abstract void writeError(String message) throws Exception;
}
