/*
 * ExceptionHandler.java
 *
 * Created on 8 December 2008
 *
 * Version 1.1
 *
 * Copyright (c) Kieran Greer
 */

package org.jlog2.exception;


import org.jlog2.*;
import java.lang.reflect.InvocationTargetException;


/**
 * This class handles the exception and logs a message depending on the type of exception.
 * @author Kieran Greer
 */
public class ExceptionHandler 
{
    /**
     * Handle the exception depending on its type and log an error message.
     * @param logger the logger.
     * @param level the error level.
     * @param methodName the name of the method in the class throwing the exception.
     * @param message an additional message to output as well as the error.
     * @param error the exception to process.
     * @return the exception to be processed further in code.
     */
    public static Exception handleException(Logger logger, String level, String methodName,
            String message, Exception error)
    {
        String wholeMessage;                    //the whole message        
        Exception theException;                 //the exception to process further

        theException = null;
        if (error != null)
        {
            //get licas-specific if present
            if (error instanceof InvocationTargetException)
            {
                error = (Exception)((InvocationTargetException)error).getTargetException();
            }

            if (!(error instanceof EndOfException))
            {
                //create message
                if ((message == null) || message.equals("")) 
                {
                    wholeMessage = (error.getLocalizedMessage());
                }
                else 
                {
                    wholeMessage = (message + error.getLocalizedMessage());
                }
               
                if (error instanceof WriteMessageException)
                {
                    try 
                    {
                        //log the message
                        LoggerHandler.logMessage(logger, level, methodName, wholeMessage);
                    }
                    catch (Exception ex) {}

                    if (((WriteMessageException)error).getUseOnce())
                    {
                        theException = new EndOfException(error.getLocalizedMessage());
                    }
                    else
                    {
                        theException = error;
                    }
                }
                else if (error instanceof Exception)
                {
                    try 
                    {
                        LoggerHandler.logMessage(logger, level, methodName, wholeMessage);
                        LoggerHandler.logError(logger, level, error);
                    }
                    catch (Exception ex) {}

                    theException = error;
                }
            }
            else
            {
                theException = error;
            }
        }

        return theException;
    }
    
    /**
     * Write the exception to the debug channels if the logger allows debugging 
     * at the specified level.
     * @param logger the logger.
     * @param level the error level.
     * @param methodName the name of the method in the class throwing the exception.
     * @param message an additional message to output as well as the error.
     * @param error the exception to process.
     */
    public static void debugException(Logger logger, String level, String methodName,
            String message, Exception error)
    {
        String wholeMessage;                    //the whole message
        
        if (logger.getDebug())
        {
            if ((message == null) || message.equals("")) 
            {
                wholeMessage = (error.getLocalizedMessage());
            }
            else 
            {
                wholeMessage = (message + error.getLocalizedMessage());
            }

            if (error instanceof Exception)
            {
                try 
                {
                    LoggerHandler.debugMessage(logger, level, methodName, wholeMessage);
                    LoggerHandler.debugError(logger, level, error);
                }
                catch (Exception ex) {}
            }
        }
    }
}
