/*
 * ConfigHandler.java
 *
 * Created on 7 August 2012
 *
 * Version 1.0
 *
 * Copyright (c) Kieran Greer
 */

package org.jlog2.util;


import java.io.File;


/**
 * Manages initial config settings.
 * @author Kieran Greer
 */
public class ConfigHandler 
{
    /** Default file size */
    private static final int DEFAULTFILESIZE = 10000;

    /** The name of the logger configuration file */
    private static String LOGCONFIG = "./config/logger.config";
    private static final String LOGCONFIG2 = "../config/logger.config";
    
    /** Alternative file path for the config file */
    private static String configFilePath = null;
    
    /** File path for the log files */
    private static String logFolderPath = null;


    /**
     * Set the folder path to read the config file from. Just the path and
     * not the file name. This can only be set once.
     * @param configFolderPath the folder path to the config file.
     * @return true if the config file exists in the folder, false otherwise.
     */
    public static boolean setConfigFolderPath(String configFolderPath)
    {
        File configFile;                    //config file
        
        if (configFilePath == null)
        {
            try
            {
                configFile = new File(configFolderPath);
                configFilePath = (configFile.getPath() + "/logger.config");

                configFile = new File(configFilePath);            
                if (configFile.exists()) return true;
            }
            catch (Exception ex)
            {}  
            
            configFilePath = null;
        }
        
        return false;
    }
    
    /**
     * Set the folder path to write the log files to. Just the path and
     * not the file name. This can only be set once.
     * @param thisLogFolderPath the folder path to write log files to.
     * @return true if the log file path exists, false otherwise.
     */
    public static boolean setLogFolderPath(String thisLogFolderPath)
    {
        File logFile;                           //log file
        
        if (logFolderPath == null)
        {
            try
            {
                logFile = new File(thisLogFolderPath);
                if (logFile.exists()) 
                {
                    logFolderPath = thisLogFolderPath;
                    return true;
                }
            }
            catch (Exception ex)
            {}

            logFolderPath = ".";
        }
        
        return false;
    }
    
    /**
     * Get the default log file size in terms of line number.
     * @return the value of DEFAULTFILESIZE.
     */
    public static int getDefaultFileSize()
    {
        return DEFAULTFILESIZE;
    }
    
    /**
     * Determine what the correct path to the config file is and return.
     * @return the most suitable file path for the config file.
     */
    protected static File getConfigFile()
    {
        File configFile;                    //config file
        
        configFile = null;
        if (configFilePath != null)
        {
            try
            {
                configFile = new File(configFilePath);            
                if (configFile.exists()) return configFile;
            }
            catch (Exception ex) {}
            
            configFile = null;
        }

        if (configFile == null)
        {
            try
            {
                configFile = new File(LOGCONFIG);            
                if (configFile.exists()) return configFile;
            }
            catch (Exception ex) {}
            
            configFile = null;
        }
        
        if (configFile == null)
        {
            try
            {
                configFile = new File(LOGCONFIG2);            
                if (configFile.exists()) return configFile;
            }
            catch (Exception ex) {}
            
            configFile = null;
        }
        
        return null;
    }
    
    /**
     * Get the logging folder path.
     * @return the value of logFolderPath.
     */
    protected static String getLogFolder()
    {
        if (logFolderPath == null) return ".";
        else return logFolderPath;
    }
}
