/*
 * UuidHandler.java
 *
 * Created on 15 May 2009
 *
 * Version 1.2
 *
 * Copyright (c) Kieran Greer
 */

package org.jlog2.util;


import org.jlog2.*;
import java.util.*;


/**
 * This class creates unique uuids, or uuids that are difficult to duplicate. This
 * is similar to the Java UUID creator.
 * @author Kieran Greer
 */
public class UuidHandler
{
    /** The logger */
    private static Logger logger;


    static
    {
        logger = LoggerHandler.getLogger(UuidHandler.class.getName());
        logger.setDebug(false);
    }

    /**
     * Create a new uuid that is a subset or concatenation of the Java UUID generator.
     * This is possibly more robust as there is a random delay added to the string creation.
     * @param uuidLength the number of characters in the seedUuid.
     * @return the value of the newly created uuid.
     * @throws java.lang.Exception any error.
     */
    public static String getUuid(int uuidLength) throws Exception
    {
        int i;
        int uuidCount;                          //each unit length
        String seedUuid;                        //the created seed
        String uuid;                            //new uuid
        String seedStr;                         //seed as a string
        Random rnd;                             //random number generator

        //generate random seed string
        rnd = new Random(System.currentTimeMillis());
        
        seedUuid = "";
        if (uuidLength > 5) uuidCount = (uuidLength / 5);
        else uuidCount = 1;
        
        for (i = 0; i < uuidCount; i++)
        {
            seedStr = getUuid(5, System.currentTimeMillis());
            Thread.sleep(rnd.nextInt(100));
            seedUuid += seedStr;
        }
        
        //generate uuid from seed
        uuid = "";
        for (i = 0; i < uuidLength; i++)
        {
            uuid += seedUuid.charAt(i);
        }

        return uuid;
    }
    
    /**
     * Create a new uuid that is randomly generated round the entered seed.
     * @param uuidLength the number of characters in the uuid.
     * @param seed the value to seed the uuid creator with.
     * @return the value of the newly created uuid.
     * @throws java.lang.Exception any error.
     */
    public static String getUuid(int uuidLength, long seed) throws Exception
    {
        int i;
        int seedLength;                         //seed length
        String uuid;                            //the created seedUuid
        String seedStr;                         //seed as a string
        String newSeedStr;                      //new seed as a string
        Random rnd;                             //random number generator

        //first add a temporary delay to make sure a time seed is different
        try
        {
            Thread.sleep(10);
        } 
        catch (InterruptedException ex)
        {}

        //generate new random seed
        uuid = null;
        seedStr = String.valueOf(seed);
        seedLength = seedStr.length() / 2;
        newSeedStr = seedStr.substring(seedStr.length() - seedLength);
        newSeedStr += newSeedStr;

        seed = Long.parseLong(newSeedStr);
        rnd = new Random(seed);

        //generate a sequence of random characters based on the random number generator
        uuid = "";
        for (i = 0; i < uuidLength; i++)
        {
            uuid += (char)('a' + rnd.nextInt(26));
        }

        return uuid;
    }
}
